PR23430, Indices misspelled
authorAlan Modra <amodra@gmail.com>
Tue, 24 Jul 2018 07:05:52 +0000 (16:35 +0930)
committerAlan Modra <amodra@gmail.com>
Tue, 24 Jul 2018 10:28:12 +0000 (19:58 +0930)
PR 23430
include/
* elf/common.h (SHT_SYMTAB_SHNDX): Fix comment typo.
bfd/
* dwarf2.c (dwarf_debug_section_enum): Fix comment typo.
* elf.c (bfd_section_from_shdr, elf_sort_sections): Likewise.
binutils/
* elfcomm.h (struct archive_info): Rename uses_64bit_indicies
to uses_64bit_indices.
* elfcomm.c (setup_archive): Update uses of above.
* readelf.c (process_archive): Likewise.
(get_section_type_name): Rename indicies to indices.
(get_32bit_elf_symbols, get_64bit_elf_symbols): Likewise.
(process_section_groups): Likewise.
cpu/
* or1kcommon.cpu (spr-reg-indices): Fix description typo.
opcodes/
* or1k-desc.h: Regenerate.

13 files changed:
bfd/ChangeLog
bfd/dwarf2.c
bfd/elf.c
binutils/ChangeLog
binutils/elfcomm.c
binutils/elfcomm.h
binutils/readelf.c
cpu/ChangeLog
cpu/or1kcommon.cpu
include/ChangeLog
include/elf/common.h
opcodes/ChangeLog
opcodes/or1k-desc.h

index 370289d38315ded89bba3680d27ba538c87467b5..bdbb3ff4f472ff0c06cd55cee7ac28a891192941 100644 (file)
@@ -1,3 +1,9 @@
+2018-07-24  Alan Modra  <amodra@gmail.com>
+
+       PR 23430
+       * dwarf2.c (dwarf_debug_section_enum): Fix comment typo.
+       * elf.c (bfd_section_from_shdr, elf_sort_sections): Likewise.
+
 2018-07-23  Max Filippov  <jcmvbkbc@gmail.com>
 
        * elf32-xtensa.c (elf_xtensa_finish_dynamic_sections): Move
index 0f8257f6015e5eb07b114d26d7a6a74b66d57d8f..8fadb5c4b62b82eedb122bc993375480be88d465 100644 (file)
@@ -345,7 +345,7 @@ const struct dwarf_debug_section dwarf_debug_sections[] =
   { NULL,                      NULL },
 };
 
-/* NB/ Numbers in this enum must match up with indicies
+/* NB/ Numbers in this enum must match up with indices
    into the dwarf_debug_sections[] array above.  */
 enum dwarf_debug_section_enum
 {
index f72182788f9e2c5428fb23b3d951de2502d0f814..efdaf2e2565dc6089fb5fcea66661ed2a05b45ed 100644 (file)
--- a/bfd/elf.c
+++ b/bfd/elf.c
@@ -2011,7 +2011,7 @@ bfd_section_from_shdr (bfd *abfd, unsigned int shindex)
   if (++ nesting > 3)
     {
       /* PR17512: A corrupt ELF binary might contain a recursive group of
-        sections, with each the string indicies pointing to the next in the
+        sections, with each the string indices pointing to the next in the
         loop.  Detect this here, by refusing to load a section that we are
         already in the process of loading.  We only trigger this test if
         we have nested at least three sections deep as normal ELF binaries
@@ -5140,7 +5140,7 @@ elf_sort_sections (const void *arg1, const void *arg2)
     {
       if (TOEND (sec2))
        {
/* If the indicies are the same, do not return 0
             here, but continue to try the next comparison.  */
          if (sec1->target_index - sec2->target_index != 0)
            return sec1->target_index - sec2->target_index;
index 63e667cde995331abde051359b7edc082b204523..25caf2977b65835f78890d18eba33ebbd8cb00ea 100644 (file)
@@ -1,3 +1,14 @@
+2018-07-24  Alan Modra  <amodra@gmail.com>
+
+       PR 23430
+       * elfcomm.h (struct archive_info): Rename uses_64bit_indicies
+       to uses_64bit_indices.
+       * elfcomm.c (setup_archive): Update uses of above.
+       * readelf.c (process_archive): Likewise.
+       (get_section_type_name): Rename indicies to indices.
+       (get_32bit_elf_symbols, get_64bit_elf_symbols): Likewise.
+       (process_section_groups): Likewise.
+
 2018-07-20  Maciej W. Rozycki  <macro@mips.com>
 
        * MAINTAINERS: Update my e-mail address, downgrade to MIPS I-IV
index 3fcd79e817ec8bd8f9f3a1cfa6fbd5c72fcd072e..9bfc33c8f175ddf907f6fb6b29d46392ec5f44c8 100644 (file)
@@ -622,7 +622,7 @@ setup_archive (struct archive_info *arch, const char *file_name,
   arch->longnames_size = 0;
   arch->nested_member_origin = 0;
   arch->is_thin_archive = is_thin_archive;
-  arch->uses_64bit_indicies = FALSE;
+  arch->uses_64bit_indices = FALSE;
   arch->next_arhdr_offset = SARMAG;
 
   /* Read the first archive member header.  */
@@ -649,7 +649,7 @@ setup_archive (struct archive_info *arch, const char *file_name,
     }
   else if (const_strneq (arch->arhdr.ar_name, "/SYM64/         "))
     {
-      arch->uses_64bit_indicies = TRUE;
+      arch->uses_64bit_indices = TRUE;
       if (! process_archive_index_and_symbols (arch, 8, read_symbols))
        return 1;
     }
index 8a08ebfa9d4bf2b679ccfecec8492b25bf2bae96..7d25815d7158da8cd5a4cae0914f064a87cda481 100644 (file)
@@ -65,7 +65,7 @@ struct archive_info
   unsigned long nested_member_origin;   /* Origin in the nested archive of the current member.  */
   unsigned long next_arhdr_offset;      /* Offset of the next archive header.  */
   bfd_boolean is_thin_archive;          /* TRUE if this is a thin archive.  */
-  bfd_boolean uses_64bit_indicies;      /* TRUE if the index table uses 64bit entries.  */
+  bfd_boolean uses_64bit_indices;       /* TRUE if the index table uses 64bit entries.  */
   struct ar_hdr arhdr;                  /* Current archive header.  */
 };
 
index 63d3453ea18580748d3c50fc3bd070acfdff6f21..7c5a0266bddf92162b1d915be051926a17fffb67 100644 (file)
@@ -4217,7 +4217,7 @@ get_section_type_name (Filedata * filedata, unsigned int sh_type)
     case SHT_PREINIT_ARRAY:    return "PREINIT_ARRAY";
     case SHT_GNU_HASH:         return "GNU_HASH";
     case SHT_GROUP:            return "GROUP";
-    case SHT_SYMTAB_SHNDX:     return "SYMTAB SECTION INDICIES";
+    case SHT_SYMTAB_SHNDX:     return "SYMTAB SECTION INDICES";
     case SHT_GNU_verdef:       return "VERDEF";
     case SHT_GNU_verneed:      return "VERNEED";
     case SHT_GNU_versym:       return "VERSYM";
@@ -5485,7 +5485,7 @@ get_32bit_elf_symbols (Filedata *           filedata,
          shndx = (Elf_External_Sym_Shndx *) get_data (NULL, filedata,
                                                       entry->hdr->sh_offset,
                                                       1, entry->hdr->sh_size,
-                                                      _("symbol table section indicies"));
+                                                      _("symbol table section indices"));
          if (shndx == NULL)
            goto exit_point;
          /* PR17531: file: heap-buffer-overflow */
@@ -5598,7 +5598,7 @@ get_64bit_elf_symbols (Filedata *           filedata,
          shndx = (Elf_External_Sym_Shndx *) get_data (NULL, filedata,
                                                       entry->hdr->sh_offset,
                                                       1, entry->hdr->sh_size,
-                                                      _("symbol table section indicies"));
+                                                      _("symbol table section indices"));
          if (shndx == NULL)
            goto exit_point;
          /* PR17531: file: heap-buffer-overflow */
@@ -6842,7 +6842,7 @@ process_section_groups (Filedata * filedata)
                      error (_("section [%5u] in group section [%5u] > maximum section [%5u]\n"),
                             entry, i, filedata->file_header.e_shnum - 1);
                      if (num_group_errors == 10)
-                       warn (_("Further error messages about overlarge group section indicies suppressed\n"));
+                       warn (_("Further error messages about overlarge group section indices suppressed\n"));
                    }
                  continue;
                }
@@ -19027,7 +19027,7 @@ process_archive (Filedata * filedata, bfd_boolean is_thin_archive)
              l += strnlen (arch.sym_table + l, arch.sym_size - l) + 1;
            }
 
-         if (arch.uses_64bit_indicies)
+         if (arch.uses_64bit_indices)
            l = (l + 7) & ~ 7;
          else
            l += l & 1;
index affb4d70e078dbb2af6c42f35e633eadd168e69e..e3074582cbe5474f97b7b3780a92c15a9a7da498 100644 (file)
@@ -1,3 +1,8 @@
+2018-07-24  Alan Modra  <amodra@gmail.com>
+
+       PR 23430
+       * or1kcommon.cpu (spr-reg-indices): Fix description typo.
+
 2018-05-09  Sebastian Rasmussen  <sebras@gmail.com>
 
        * or1kcommon.cpu (spr-reg-info): Typo fix.
index 86d440c3850d3f916eb4095ec103e71cccb44a56..c0e4f316adf15f8a3e5ec7c6056804e766148780 100644 (file)
 
 (define-normal-enum
   spr-reg-indices
-  "special purpose register indicies"
+  "special purpose register indices"
   ()
   SPR-INDEX-
   (.map (.pmacro (args)
index 64224c6e00bc59899aff86b743c83e5751ca85e4..c408eb7d4ca66cdb5421fb5623434386ad3c0e62 100644 (file)
@@ -1,3 +1,8 @@
+2018-07-24  Alan Modra  <amodra@gmail.com>
+
+       PR 23430
+       * elf/common.h (SHT_SYMTAB_SHNDX): Fix comment typo.
+
 2018-07-20  Chenghua Xu  <paul.hua.gm@gmail.com>
            Maciej W. Rozycki  <macro@mips.com>
 
index 773f378fde1c25081b9176bd5aeeeb995b5958ec..3a6244dc6dc9bb8f1719f8f436deec5baffeb005 100644 (file)
 #define SHT_FINI_ARRAY   15            /* Array of ptrs to finish functions */
 #define SHT_PREINIT_ARRAY 16           /* Array of ptrs to pre-init funcs */
 #define SHT_GROUP        17            /* Section contains a section group */
-#define SHT_SYMTAB_SHNDX  18           /* Indicies for SHN_XINDEX entries */
+#define SHT_SYMTAB_SHNDX  18           /* Indices for SHN_XINDEX entries */
 
 #define SHT_LOOS       0x60000000      /* First of OS specific semantics */
 #define SHT_HIOS       0x6fffffff      /* Last of OS specific semantics */
index acd044b17013d9454318e75f0352a5c72482ee58..0c232f7fa4c8fb7767395793ca3b07f80e8beb70 100644 (file)
@@ -1,3 +1,8 @@
+2018-07-24  Alan Modra  <amodra@gmail.com>
+
+       PR 23430
+       * or1k-desc.h: Regenerate.
+
 2018-07-24  Jan Beulich  <jbeulich@suse.com>
 
        * i386-dis-evex.h (evex_table): Add %LQ to vcvtsi2ss, vcvtsi2sd,
index 6112fc130b1b6c86e7c0eece45eb8863106f75ec..894a8bb462a8a2680b881c822de70b8d56519e3e 100644 (file)
@@ -78,7 +78,7 @@ typedef enum spr_groups {
  , SPR_GROUP_POWER, SPR_GROUP_PIC, SPR_GROUP_TICK, SPR_GROUP_FPU
 } SPR_GROUPS;
 
/* Enum declaration for special purpose register indicies.  */
 typedef enum spr_reg_indices {
   SPR_INDEX_SYS_VR = 0, SPR_INDEX_SYS_UPR = 1, SPR_INDEX_SYS_CPUCFGR = 2, SPR_INDEX_SYS_DMMUCFGR = 3
  , SPR_INDEX_SYS_IMMUCFGR = 4, SPR_INDEX_SYS_DCCFGR = 5, SPR_INDEX_SYS_ICCFGR = 6, SPR_INDEX_SYS_DCFGR = 7
@@ -5140,7 +5140,7 @@ elf_sort_sections (const void *arg1, const void *arg2)
       if (TOEND (sec2))
        {
-         /* If the indicies are the same, do not return 0
+         /* If the indices are the same, do not return 0
             here, but continue to try the next comparison.  */
          if (sec1->target_index - sec2->target_index != 0)
@@ -78,7 +78,7 @@ typedef enum spr_groups {
 } SPR_GROUPS;
 
-/* Enum declaration for special purpose register indicies.  */
+/* Enum declaration for special purpose register indices.  */
 typedef enum spr_reg_indices {
   SPR_INDEX_SYS_VR = 0, SPR_INDEX_SYS_UPR = 1, SPR_INDEX_SYS_CPUCFGR = 2, SPR_INDEX_SYS_DMMUCFGR = 3
This page took 0.038489 seconds and 4 git commands to generate.